@@ -89,6 +89,7 @@ CROSSMODULE_WRAPPER(create_compressed_chunk);
 CROSSMODULE_WRAPPER(compress_chunk);
 CROSSMODULE_WRAPPER(decompress_chunk);
 CROSSMODULE_WRAPPER(bloom1_contains);
+CROSSMODULE_WRAPPER(bloom1_contains_any);
 
 /* continuous aggregate */
 CROSSMODULE_WRAPPER(continuous_agg_refresh);
@@ -167,7 +168,7 @@ error_no_default_fn_pg_community(PG_FUNCTION_ARGS)
 	ereport(ERROR,
 			(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
 			 errmsg("function \"%s\" is not supported under the current \"%s\" license",
-					get_func_name(fcinfo->flinfo->fn_oid),
+					fcinfo->flinfo ? get_func_name(fcinfo->flinfo->fn_oid) : "unknown",
 					ts_guc_license),
 			 errhint("Upgrade your license to 'timescale' to use this free community feature.")));
 
@@ -403,6 +404,7 @@ TSDLLEXPORT CrossModuleFunctions ts_cm_functions_default = {
 	.uuid_compressor_append = error_no_default_fn_pg_community,
 	.uuid_compressor_finish = error_no_default_fn_pg_community,
 	.bloom1_contains = error_no_default_fn_pg_community,
+	.bloom1_contains_any = error_no_default_fn_pg_community,
 	.bloom1_get_hash_function = bloom1_get_hash_function_default,
 
 	.decompress_batches_for_insert = error_no_default_fn_chunk_insert_state_community,
