@@ -15,6 +15,7 @@
 #include <parser/parser.h>
 #include <storage/lmgr.h>
 #include <utils/builtins.h>
+#include <utils/elog.h>
 #include <utils/lsyscache.h>
 #include <utils/typcache.h>
 
@@ -129,14 +130,30 @@ parse_segment_collist(char *inpstr, Hypertable *hypertable)
 					 quote_identifier(NameStr(hypertable->fd.table_name)),
 					 inpstr);
 
+	const MemoryContext oldcontext = CurrentMemoryContext;
+
 	PG_TRY();
 	{
 		parsed = raw_parser(buf.data, RAW_PARSE_DEFAULT);
 	}
 	PG_CATCH();
 	{
-		throw_segment_by_error(inpstr);
-		PG_RE_THROW();
+		/* We do this fandango to avoid exhausting the error stack if we get
+		 * anything else but a syntax error, for example, an out of memory
+		 * error. */
+		ErrorData *edata;
+		MemoryContextSwitchTo(oldcontext);
+		edata = CopyErrorData();
+		FlushErrorState();
+		if (edata->sqlerrcode == ERRCODE_SYNTAX_ERROR)
+		{
+			edata->cursorpos = edata->internalpos = 0;
+			edata->detail = edata->message;
+			edata->message = psprintf("unable to parse segmenting option \"%s\"", inpstr);
+			edata->hint = psprintf("The option timescaledb.compress_segmentby must be a set of "
+								   "columns separated by commas.");
+		}
+		ReThrowError(edata);
 	}
 	PG_END_TRY();
 
@@ -235,14 +252,31 @@ ts_compress_parse_order_collist(char *inpstr, Hypertable *hypertable)
 					 quote_identifier(NameStr(hypertable->fd.table_name)),
 					 inpstr);
 
+	const MemoryContext oldcontext = CurrentMemoryContext;
+
 	PG_TRY();
 	{
 		parsed = raw_parser(buf.data, RAW_PARSE_DEFAULT);
 	}
 	PG_CATCH();
 	{
-		throw_order_by_error(inpstr);
-		PG_RE_THROW();
+		/* We do this fandango to avoid exhausting the error stack if we get
+		 * anything else but a syntax error, for example, an out of memory
+		 * error. */
+		ErrorData *edata;
+		MemoryContextSwitchTo(oldcontext);
+		edata = CopyErrorData();
+		FlushErrorState();
+		if (edata->sqlerrcode == ERRCODE_SYNTAX_ERROR)
+		{
+			edata->cursorpos = edata->internalpos = 0;
+			edata->detail = edata->message;
+			edata->message = psprintf("unable to parse ordering option \"%s\"", inpstr);
+			edata->hint = psprintf("The timescaledb.compress_orderby option must be a set of column"
+								   " names with sort options, separated by commas."
+								   " It is the same format as an ORDER BY clause.");
+		}
+		ReThrowError(edata);
 	}
 	PG_END_TRY();
 
@@ -386,6 +420,15 @@ parse_sparse_index_config(JsonbParseState *parse_state, FuncCall *sparse_index_d
 											sparse_index_with_clause_def,
 											TS_ARRAY_LEN(sparse_index_with_clause_def));
 	config.base.source = _SparseIndexSourceEnumConfig;
+
+	if (list_length(sparse_index_details->args) != 1)
+	{
+		ereport(ERROR,
+				(errcode(ERRCODE_SYNTAX_ERROR),
+				 errmsg("sparse index \"%s\" can only have one column",
+						ts_sparse_index_type_names[config.base.type])));
+	}
+
 	/* validate and extract column */
 	Node *arg = list_nth(sparse_index_details->args, 0);
 
@@ -440,7 +483,9 @@ parse_sparse_index_config(JsonbParseState *parse_state, FuncCall *sparse_index_d
 				ereport(ERROR,
 						(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
 						 errmsg("Creating bloom sparse index is disabled"),
-						 errhint("Set \"enable_sparse_index_bloom\" to true.")));
+						 errhint("Either set \"enable_sparse_index_bloom\" to true or remove the "
+								 "bloom filter indexes from \"sparse_index\" configuration of the "
+								 "hypertable.")));
 			}
 			/*
 			 * The column type must be hashable. For some types we use our own hash functions
@@ -505,14 +550,28 @@ parse_sparse_index_config_list(char *inpstr, Hypertable *hypertable)
 	/* parse the sparse index list exactly how you would targetlist */
 	appendStringInfo(&buf, "SELECT %s", inpstr);
 
+	const MemoryContext oldcontext = CurrentMemoryContext;
+
 	PG_TRY();
 	{
 		parsed = raw_parser(buf.data, RAW_PARSE_DEFAULT);
 	}
 	PG_CATCH();
 	{
-		throw_sparse_index_error(inpstr);
-		PG_RE_THROW();
+		/* We do this fandango to avoid exhausting the error stack if we get
+		 * anything else but a syntax error, for example, an out of memory
+		 * error. */
+		ErrorData *edata;
+		MemoryContextSwitchTo(oldcontext);
+		edata = CopyErrorData();
+		FlushErrorState();
+		if (edata->sqlerrcode == ERRCODE_SYNTAX_ERROR)
+		{
+			edata->cursorpos = edata->internalpos = 0;
+			edata->detail = edata->message;
+			edata->message = psprintf("unable to parse sparse index option \"%s\"", inpstr);
+		}
+		ReThrowError(edata);
 	}
 	PG_END_TRY();
 
