@@ -20,6 +20,7 @@
 #include <utils/typcache.h>
 
 #include <compat/compat.h>
+#include <chunk_insert_state.h>
 #include <compression/arrow_c_data_interface.h>
 #include <compression/compression.h>
 #include <compression/compression_dml.h>
@@ -27,10 +28,8 @@
 #include <compression/wal_utils.h>
 #include <expression_utils.h>
 #include <indexing.h>
-#include <nodes/chunk_dispatch/chunk_dispatch.h>
-#include <nodes/chunk_dispatch/chunk_insert_state.h>
-#include <nodes/decompress_chunk/vector_dict.h>
-#include <nodes/decompress_chunk/vector_predicates.h>
+#include <nodes/columnar_scan/vector_dict.h>
+#include <nodes/columnar_scan/vector_predicates.h>
 #include <nodes/modify_hypertable.h>
 #include <ts_catalog/array_utils.h>
 
@@ -58,8 +57,7 @@ static void process_predicates(Chunk *ch, CompressionSettings *settings, List *p
 							   List **heap_filters, List **index_filters, List **is_null);
 static Relation find_matching_index(Relation comp_chunk_rel, List **index_filters,
 									List **heap_filters);
-static tuple_filtering_constraints *
-get_batch_keys_for_unique_constraints(const ChunkInsertState *cis, Relation relation);
+static tuple_filtering_constraints *get_batch_keys_for_unique_constraints(Relation relation);
 static BatchFilter *make_batchfilter(char *column_name, StrategyNumber strategy, Oid collation,
 									 RegProcedure opcode, Const *value, bool is_null_check,
 									 bool is_null, bool is_array_op);
@@ -109,8 +107,10 @@ init_decompress_state_for_insert(ChunkInsertState *cis, TupleTableSlot *slot)
 
 	if (cdst->has_primary_or_unique_index)
 	{
-		tuple_filtering_constraints *constraints =
-			get_batch_keys_for_unique_constraints(cis, cis->rel);
+		tuple_filtering_constraints *constraints = get_batch_keys_for_unique_constraints(cis->rel);
+		if (constraints->covered)
+			constraints->on_conflict = cis->onConflictAction;
+
 		cdst->constraints = constraints;
 
 		CompressionSettings *compression_settings =
@@ -1098,7 +1098,7 @@ decompress_chunk_walker(PlanState *ps, struct decompress_chunk_context *ctx)
  *
  */
 static tuple_filtering_constraints *
-get_batch_keys_for_unique_constraints(const ChunkInsertState *cis, Relation relation)
+get_batch_keys_for_unique_constraints(Relation relation)
 {
 	tuple_filtering_constraints *constraints = palloc0(sizeof(tuple_filtering_constraints));
 	constraints->on_conflict = ONCONFLICT_UPDATE;
@@ -1181,11 +1181,6 @@ get_batch_keys_for_unique_constraints(const ChunkInsertState *cis, Relation rela
 			return constraints;
 	}
 
-	if (constraints->covered && cis->cds && cis->cds->dispatch)
-	{
-		constraints->on_conflict = ts_chunk_dispatch_get_on_conflict_action(cis->cds->dispatch);
-	}
-
 	return constraints;
 }
 
@@ -1736,6 +1731,9 @@ can_delete_without_decompression(ModifyHypertableState *ht_state, CompressionSet
 	if (ht_state->mt->returningLists)
 		return false;
 
+	if (ts_hypertable_has_continuous_aggregates(ht_state->ht->fd.id))
+		return false;
+
 	/*
 	 * If there are any DELETE row triggers on the hypertable we skip the optimization
 	 * to delete compressed batches directly.
