@@ -42,3 +42,5 @@ void continuous_agg_update_materialization(Hypertable *mat_ht, const ContinuousA
 										   SchemaAndName materialization_table,
 										   const NameData *time_column_name,
 										   InternalTimeRange materialization_range, int32 chunk_id);
+bool continuous_agg_has_pending_materializations(const ContinuousAgg *cagg,
+												 InternalTimeRange materialization_range);
