@@ -12,7 +12,7 @@
 
 #include "compression/arrow_c_data_interface.h"
 #include "hash64.h"
-#include "nodes/decompress_chunk/compressed_batch.h"
+#include "nodes/columnar_scan/compressed_batch.h"
 #include "nodes/vector_agg/exec.h"
 #include "nodes/vector_agg/grouping_policy_hash.h"
 #include "template_helper.h"
