@@ -20,7 +20,6 @@
 #include "guc.h"
 #include "hypertable.h"
 #include "nodes/columnar_scan/columnar_scan.h"
-#include "nodes/frozen_chunk_dml/frozen_chunk_dml.h"
 #include "nodes/gapfill/gapfill.h"
 #include "nodes/skip_scan/skip_scan.h"
 #include "nodes/vector_agg/plan.h"
@@ -31,19 +30,6 @@
 
 #define OSM_EXTENSION_NAME "timescaledb_osm"
 
-static int osm_present = -1;
-
-static bool
-is_osm_present()
-{
-	if (osm_present == -1)
-	{
-		Oid osm_oid = get_extension_oid(OSM_EXTENSION_NAME, true);
-		osm_present = OidIsValid(osm_oid);
-	}
-	return osm_present;
-}
-
 static bool
 involves_hypertable(PlannerInfo *root, RelOptInfo *parent)
 {
@@ -153,20 +139,6 @@ void
 tsl_set_rel_pathlist_dml(PlannerInfo *root, RelOptInfo *rel, Index rti, RangeTblEntry *rte,
 						 Hypertable *ht)
 {
-	if (is_osm_present())
-	{
-		Chunk *chunk = ts_chunk_get_by_relid(rte->relid, false);
-		if (chunk && ts_chunk_is_frozen(chunk))
-		{
-			ListCell *lc;
-			foreach (lc, rel->pathlist)
-			{
-				Path **pathptr = (Path **) &lfirst(lc);
-				*pathptr = frozen_chunk_dml_generate_path(*pathptr, chunk);
-			}
-			return;
-		}
-	}
 	/*
 	 * We do not support MERGE command with UPDATE/DELETE merge actions on
 	 * compressed hypertables, because Custom Scan (ModifyHypertable) node is
