@@ -133,3 +133,67 @@ ORDER BY
     time_bucket_gapfill('5 minutes', m.time, start := '2025-07-05 23:55:00+00:00'::timestamptz,
                         finish := '2025-07-06 00:30:00+00:00'::timestamptz),  -- avoid alias here
     m.position_id,m.src_mac_id, m.stream_index, m.measurement_type;
+
+-- Fix for #4894: gapfill error over aggregates in expressions with groupby columns and columns out of order
+CREATE TABLE hourly (
+    time timestamptz NOT NULL,
+    signal smallint NOT NULL,
+    value real,
+    level_a integer,
+    level_b smallint,
+    level_c smallint,
+    agg smallint
+);
+
+INSERT into hourly(time, signal,value, level_a, level_b, level_c, agg) values
+('2022-10-01T00:00:00Z', 2, 685, 1, -1, -1, 2 ),
+('2022-10-01T00:00:00Z', 2, 686, 1, -1, -1, 3 ),
+('2022-10-01T02:00:00Z', 2, 686, 1, -1, -3, 2 ),
+('2022-10-01T02:00:00Z', 2, 687, 1, -1, -1, 3 ),
+('2022-10-01T03:00:00Z', 2, 687, 1, -1, -3, 2 ),
+('2022-10-01T03:00:00Z', 2, 688, 1, -1, -1, 3 );
+
+-- Expression over 1 aggregate and 1 groupby column
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ CASE WHEN agg in (0,3) THEN max(value) ELSE null END as max,
+ CASE WHEN agg in (0,2) THEN min(value) ELSE null END as min
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b >= -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg order by 1,2,3;
+
+-- Expression over 2 aggregates and 1 groupby column
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ CASE WHEN agg in (0,3) THEN max(value) ELSE min(level_c) END as maxmin
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b = -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg order by 1,2;
+
+-- Expression over 2 aggregates and 2 groupby columns
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ CASE WHEN agg in (0,3) THEN max(value) ELSE min(level_c)+signal END as maxmin
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b = -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg, signal order by 1,2;
+
+-- Expressions over aggregates and complex groupby expressions
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ max(value)+(agg+1)
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b = -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg+1 order by 1,2;
+
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ max(value)+(agg+1)+(agg+1+1)
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b = -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg+1, agg+1+1 order by 1,2;
+
+SELECT
+ time_bucket_gapfill('1 hour', time) as time,
+ max(value) + (agg+signal) maxv,
+ min(value) - (agg+signal) minv,
+ agg+signal
+ FROM hourly WHERE agg in (0,2,3) and signal in (2) AND level_a = 1 AND level_b = -1 AND time >= '2022-10-01T00:00:00Z' AND time < '2022-10-01T05:59:59Z'
+ GROUP BY 1,  agg+signal order by 1,2,3;
+
+drop table hourly cascade;
