@@ -17,12 +17,12 @@ explain (buffers off, costs off) select * from sparse where value = 1;
 
 -- Should be disabled with the GUC
 set timescaledb.auto_sparse_indexes to off;
-select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
+select count(compress_chunk(x, recompress:=true)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 explain (buffers off, costs off) select * from sparse where value = 1;
 
 reset timescaledb.auto_sparse_indexes;
-select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
+select count(compress_chunk(x, recompress:=true)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 explain (buffers off, costs off) select * from sparse where value = 1;
 
@@ -37,7 +37,7 @@ explain (buffers off, costs off) select * from sparse where value = 1;
 -- Not for expression indexes.
 drop index ii;
 create index ii on sparse((value + 1));
-select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
+select count(compress_chunk(x, recompress:=true)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 explain (buffers off, costs off) select * from sparse where value = 1;
 
@@ -45,14 +45,14 @@ explain (buffers off, costs off) select * from sparse where value = 1;
 -- Not for other index types.
 drop index ii;
 create index ii on sparse using hash(value);
-select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
+select count(compress_chunk(x, recompress:=true)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 explain (buffers off, costs off) select * from sparse where value = 1;
 
 
 -- When the chunk is recompressed without index, no sparse index is created.
 drop index ii;
-select count(compress_chunk(decompress_chunk(x))) from show_chunks('sparse') x;
+select count(compress_chunk(x, recompress:=true)) from show_chunks('sparse') x;
 vacuum analyze sparse;
 explain (buffers off, costs off) select * from sparse where value = 1;
 
