@@ -1237,3 +1237,49 @@ ALTER TABLE mix_pg_ts RESET (fillfactor, tsdb.segmentby);
 SELECT reloptions FROM pg_class WHERE relname='mix_pg_ts';
 SELECT * FROM timescaledb_information.hypertable_compression_settings WHERE hypertable='mix_pg_ts'::regclass;
 
+-- test with compression enabled but no compressed chunks
+CREATE TABLE alter_col_type_test(time timestamptz NOT NULL, device_id int, value float);
+SELECT create_hypertable('alter_col_type_test','time');
+INSERT INTO alter_col_type_test VALUES ('2025-01-01', 1, 10.5), ('2025-01-02', 2, 20.5);
+
+-- alter column type should work on hypertable without compression
+ALTER TABLE alter_col_type_test ALTER COLUMN device_id TYPE bigint;
+SELECT * FROM alter_col_type_test ORDER BY time;
+
+-- enable compression but don't compress any chunks yet
+ALTER TABLE alter_col_type_test SET (timescaledb.compress, timescaledb.compress_segmentby='device_id');
+
+-- alter column type should succeed when compression is enabled but no chunks are compressed
+ALTER TABLE alter_col_type_test ALTER COLUMN device_id TYPE int;
+ALTER TABLE alter_col_type_test ALTER COLUMN value TYPE double precision;
+
+-- verify the changes worked
+\d alter_col_type_test
+SELECT * FROM alter_col_type_test ORDER BY time;
+
+-- now compress a chunk
+SELECT compress_chunk(show_chunks('alter_col_type_test'));
+
+-- ALTER COLUMN TYPE should fail when chunks are compressed
+\set ON_ERROR_STOP 0
+ALTER TABLE alter_col_type_test ALTER COLUMN device_id TYPE text;
+\set ON_ERROR_STOP 1
+
+-- decompress and try again, should succeed
+SELECT decompress_chunk(show_chunks('alter_col_type_test'));
+ALTER TABLE alter_col_type_test ALTER COLUMN device_id TYPE bigint;
+\d alter_col_type_test
+
+-- verify we can still work with the table after type change
+SELECT * FROM alter_col_type_test ORDER BY time;
+
+-- compress again to verify compression still works
+SELECT compress_chunk(show_chunks('alter_col_type_test'));
+
+-- ALTER TYPE should fail again when compressed
+\set ON_ERROR_STOP 0
+ALTER TABLE alter_col_type_test ALTER COLUMN device_id TYPE text;
+\set ON_ERROR_STOP 1
+
+DROP TABLE alter_col_type_test;
+
