@@ -73,6 +73,7 @@ ALTER TABLE foo ALTER b SET NOT NULL;
 select attname, attnotnull from pg_attribute where attrelid = (select oid from pg_class where relname like 'foo') and attname like 'b';
 
 ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_segmentby = 'd');
+ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = '');
 ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'd');
 ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'c desc nulls');
 ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'c desc nulls thirsty');
@@ -101,12 +102,40 @@ ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'b, b'
 
 --should succeed
 ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'a, b');
+ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'a, b', timescaledb.compress_segmentby='');
+ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'a, b', timescaledb.compress_segmentby='c');
+
+-- test alter reset
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+ALTER TABLE foo RESET (timescaledb.compress_orderby);
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+ALTER TABLE foo RESET (timescaledb.compress_segmentby);
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+ALTER TABLE foo set (timescaledb.compress, timescaledb.compress_orderby = 'a, b', timescaledb.compress_index = 'bloom(c)');
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+ALTER TABLE foo RESET (timescaledb.compress_index);
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+-- should fail
+ALTER TABLE foo RESET (timescaledb.compress);
+ALTER TABLE foo RESET (timescaledb.compress, timescaledb.compress_segmentby, timescaledb.compress_orderby);
+ALTER TABLE foo RESET (timescaledb.compress_segmentby = 'a', timescaledb.compress_orderby);
+ALTER TABLE foo RESET (timescaledb.compress_segmentby = '');
+
+-- should succeed
+ALTER TABLE foo RESET (timescaledb.compress_segmentby, timescaledb.compress_orderby);
+SELECT * FROM _timescaledb_catalog.compression_settings WHERE relid = 'foo'::regclass;
+ALTER TABLE foo SET (timescaledb.compress, timescaledb.compress_orderby = 'a, b', timescaledb.compress_segmentby='');
+
+create table foo_fake (a integer, b integer, c integer, t text, p point);
+ALTER TABLE foo_fake RESET (timescaledb.compress_segmentby);
+select table_name from create_hypertable('foo_fake', 'a', chunk_time_interval=> 10);
+ALTER TABLE foo_fake RESET (timescaledb.compress_segmentby);
+DROP TABLE foo_fake;
 
 --ddl on ht with compression
 ALTER TABLE foo DROP COLUMN a;
 ALTER TABLE foo DROP COLUMN b;
 ALTER TABLE foo ALTER COLUMN t SET NOT NULL;
-ALTER TABLE foo RESET (timescaledb.compress);
 
 --can add constraints as long as no data is compressed
 ALTER TABLE foo ADD CONSTRAINT chk CHECK(b > 0);
@@ -420,8 +449,7 @@ SELECT create_hypertable('main_table', 'time', chunk_time_interval => interval '
 
 ALTER TABLE main_table SET (
     timescaledb.compress,
-    timescaledb.compress_segmentby = 'device_id',
-    timescaledb.compress_orderby = '');
+    timescaledb.compress_segmentby = 'device_id');
 
 SELECT compress_chunk(show_chunks('main_table'));
 
@@ -488,7 +516,7 @@ ALTER TABLE table_unique_index SET (timescaledb.compress);
 ALTER TABLE table_unique_index SET (timescaledb.compress = off);
 ALTER TABLE table_unique_index SET (timescaledb.compress, timescaledb.compress_segmentby = 'location');
 ALTER TABLE table_unique_index SET (timescaledb.compress = off);
-ALTER TABLE table_unique_index SET (timescaledb.compress, timescaledb.compress_orderby = 'device_id');
+ALTER TABLE table_unique_index SET (timescaledb.compress, timescaledb.compress_orderby = 'device_id', timescaledb.compress_segmentby = '');
 ALTER TABLE table_unique_index SET (timescaledb.compress = off);
 -- Will enable compression without warnings
 ALTER TABLE table_unique_index SET (timescaledb.compress, timescaledb.compress_segmentby = 'location', timescaledb.compress_orderby = 'device_id');
