@@ -25,25 +25,25 @@ alter table t set (timescaledb.compress = true, timescaledb.compress_segmentby =
 select count(compress_chunk(x, true)) from show_chunks('t') x;
 analyze t;
 
-explain (costs off) select * from t order by ts;
-explain (costs off) select * from t where low_card = 1 order by ts;
-explain (costs off) select * from t where high_card = 1 order by ts;
-explain (costs off) select * from t where low_card = 1 and high_card = 1 order by ts;
+explain (buffers off, costs off) select * from t order by ts;
+explain (buffers off, costs off) select * from t where low_card = 1 order by ts;
+explain (buffers off, costs off) select * from t where high_card = 1 order by ts;
+explain (buffers off, costs off) select * from t where low_card = 1 and high_card = 1 order by ts;
 
 -- Test that batch sorted merge is not disabled by enable_sort. We have another
 -- GUC to disable it.
 set enable_sort to off;
-explain (costs off) select * from t where high_card = 1 order by ts;
+explain (buffers off, costs off) select * from t where high_card = 1 order by ts;
 reset enable_sort;
 
 -- Test that inequality conditions in WHERE also influence the estimates.
-explain (costs off) select * from t where high_card < 10 order by ts;
-explain (costs off) select * from t where high_card < 500 order by ts;
+explain (buffers off, costs off) select * from t where high_card < 10 order by ts;
+explain (buffers off, costs off) select * from t where high_card < 500 order by ts;
 
 
 -- Test that batch sorted merge respects the working memory limit.
 set work_mem to 64;
-explain (costs off) select * from t where high_card < 10 order by ts;
+explain (buffers off, costs off) select * from t where high_card < 10 order by ts;
 reset work_mem;
 
 -- Test for large values of memory limit bytes that don't fit into an int.
@@ -52,7 +52,7 @@ reset work_mem;
 -- on the architecture.
 select least(4194304, max_val::bigint) large_work_mem from pg_settings where name = 'work_mem' \gset
 set work_mem to :large_work_mem;
-explain (costs off) select * from t where high_card < 10 order by ts;
+explain (buffers off, costs off) select * from t where high_card < 10 order by ts;
 reset work_mem;
 
 reset max_parallel_workers_per_gather;
