@@ -6,7 +6,7 @@
 -- We need memory usage in PortalContext after the completion of the query, so
 -- we'll have to log it from a trigger that runs after the query is completed.
 
-\c :TEST_DBNAME :ROLE_CLUSTER_SUPERUSER;
+\c :TEST_DBNAME :ROLE_SUPERUSER;
 
 create table uk_price_paid(price integer, "date" date, postcode1 text, postcode2 text, type smallint, is_new bool, duration smallint, addr1 text, addr2 text, street text, locality text, town text, district text, country text, category smallint);
 alter table uk_price_paid set unlogged;
